import { TemplateObject } from "logimat";
/**
 * Creates a new behavior.
 * Usage: createBehavior!(name: string);
 */
export declare const createBehavior: TemplateObject;
/**
 * Marks a behavior's variable as mutable (changable after compilation).
 * Usage: setBehaviorMut!(name: string, variableName: string);
 */
export declare const setBehaviorMut: TemplateObject;
/**
 * Get the value of a behavior's variable.
 * Usage: getBehaviorVal!(name: string, variableName: string)
 */
export declare const getBehaviorVal: TemplateObject;
/**
 * Set the value of a behavior's variable (during compilation). This must be used before a variable is marked as mutable.
 * Usage: setBehaviorVal!(name: string, variableName: string, val: number);
 */
export declare const setBehaviorVal: TemplateObject;
/**
 * Set the value of a behavior's variable (during compilation) using an argument that was passed to the behavior when it was added to the GameObject. This must be used before a variable is marked as mutable.
 * Usage: setBehaviorValArgs!(name: string, variableName: string, arg: number);
 */
export declare const setBehaviorValArgs: TemplateObject;
/**
 * Set the value of a behavior's variable on update (during runtime). This must be used after a variable is marked as mutable.
 * Usage: setBehaviorValAction!(name: string, variableName: string, body: ActionBody);
 */
export declare const setBehaviorValAction: TemplateObject;
/**
 * Create an action that sets the value of a behavior's variable (during runtime). This must be ran manually. This must be used after a variable is marked as mutable.
 * Usage: noRegisterSetBehaviorValAction!(name: string, variableName: string, body: ActionBody, actionName: string);
 */
export declare const noRegisterSetBehaviorValAction: TemplateObject;
/**
 * Create a graph of this object.
 * If only one body is defined, the graph will use 1=body1, and body1=body2 otherwise.
 * Usage: behaviorGraph!(name: string, body1: ActionBody, operator?: string, body2?: ActionBody);
 */
export declare const behaviorGraph: TemplateObject;
/**
 * Gets an argument that was passed to the behavior when it was added to the GameObject.
 * Usage getBehaviorArgs!(arg: number);
 */
export declare const getBehaviorArgs: TemplateObject;
/**
 * Finalize the behavior. This must be the last template called on the behavior.
 * Usage: finalizeBehavior!(name: string);
 */
export declare const finalizeBehavior: TemplateObject;
