"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.finalize = exports.initialize = void 0;
const util_1 = require("../util");
const transform_1 = __importDefault(require("../init/transform"));
const circle_1 = __importDefault(require("../init/circle"));
/**
 * Initialize the game. This must be the first template called.
 */
exports.initialize = {
    function: (args, state, context) => {
        (0, util_1.ensureState)(state);
        (0, util_1.outerCheck)(context);
        return transform_1.default + circle_1.default;
    }
};
/**
 * Finalize the game. This must be the last template called.
 * Usage: finalize!();
 */
exports.finalize = {
    function: (args, state, context) => {
        (0, util_1.ensureState)(state);
        (0, util_1.outerCheck)(context);
        const output = [];
        if (args.length < 1) {
            for (const action of state.graphgame.postActions) {
                output.push(action(state));
            }
            return output.join("\n") + "\nfinalize!(1);";
        }
        for (const name in state.graphgame.actions) {
            const val = state.graphgame.actions[name];
            output.push(`action ${name + "update"} = ${name} {
                state = ${val};
            }`);
            state.graphgame.finalActions.push(name + "update");
        }
        if (state.graphgame.finalActions.length > 0)
            output.push("actions m_ain = " + state.graphgame.finalActions.join(", ") + ";");
        return output.join("\n");
    }
};
//# sourceMappingURL=main.js.map