"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Behavior = void 0;
class Behavior {
    constructor(name) {
        this.parts = [];
        this.postParts = [];
        this.finalized = false;
        this.name = name;
    }
    /**
     * Add a new part to the behavior.
     */
    add(val) {
        this.parts.push(val);
    }
    /**
     * Add a new post part to the behavior.
     */
    addPost(val) {
        this.postParts.push(val);
    }
    /**
     * Mark the behavior as finalized.
     */
    finalize() {
        this.finalized = true;
    }
    /**
     * Compiles the behavior for a specific object.
     */
    compile(id) {
        if (!this.finalized)
            throw new Error("A behavior must be finalized before it can be used!");
        return this.parts.map((part, idx) => part(id, idx)).join("\n");
    }
    /**
     * Compiles the post behavior for a specific object.
     */
    compilePost(id) {
        if (!this.finalized)
            throw new Error("A behavior must be finalized before it can be used!");
        return this.postParts.map((part, idx) => part(id, idx)).join("\n");
    }
}
exports.Behavior = Behavior;
//# sourceMappingURL=Behavior.js.map