"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getShortVariableName = exports.getFullVariableName = exports.getString = exports.getNum = exports.behaviorCheck = exports.getSemiMut = exports.objectVarCheck = exports.objectCheck = exports.expressionCheck = exports.outerCheck = exports.ensureState = void 0;
const logimat_1 = require("logimat");
const ensureState = (state) => {
    if (!state.hasOwnProperty("graphgame"))
        state.graphgame = { objects: {}, behaviors: {}, actions: {}, finalActions: [], finalized: false, lastObjectBehaviorId: null, lastObjectBehaviorArgs: null, postActions: [] };
    if (state.graphgame.finalized)
        throw new Error("Do not run any other templates after finalizing!");
};
exports.ensureState = ensureState;
//Context checks
const outerCheck = (context) => {
    if (context !== logimat_1.TemplateContext.OuterDeclaration)
        throw new Error("This can only be ran from outside of any functions.");
};
exports.outerCheck = outerCheck;
const expressionCheck = (context) => {
    if (context !== logimat_1.TemplateContext.Expression)
        throw new Error("This can only be ran from within an expression.");
};
exports.expressionCheck = expressionCheck;
//GameObject checks
const objectCheck = (state, id) => {
    if (!state.graphgame.objects.hasOwnProperty(id))
        throw new Error("An object with the ID \"" + id + "\" does not exist!");
};
exports.objectCheck = objectCheck;
const objectVarCheck = (state, id, name) => {
    if (!state.graphgame.objects[id].hasOwnProperty(name))
        throw new Error("A variable with the name \"" + name + "\" does not exist!");
};
exports.objectVarCheck = objectVarCheck;
const getSemiMut = (state, id, name) => {
    return state.graphgame.objects[id][name];
};
exports.getSemiMut = getSemiMut;
//Behavior checks
const behaviorCheck = (state, name) => {
    if (!state.graphgame.behaviors.hasOwnProperty(name))
        throw new Error("A behavior with the name \"" + name + "\" does not exist!");
};
exports.behaviorCheck = behaviorCheck;
//Arg checks
const getNum = (args, state, idx, error = null) => {
    if (args.length < idx + 1 || typeof (args[idx]) !== "number" || isNaN(args[idx])) {
        if (error)
            throw new Error(error);
        else
            return null;
    }
    return args[idx];
};
exports.getNum = getNum;
const getString = (args, state, idx, error = null) => {
    if (args.length < idx + 1 || typeof (args[idx]) !== "string" || !args[idx]) {
        if (error)
            throw new Error(error);
        else
            return null;
    }
    return args[idx];
};
exports.getString = getString;
//Dot access helper
const getFullVariableName = (varName, behaviorName) => (varName.startsWith("base.") ? varName.substring(5) : behaviorName + varName).replace(".", "");
exports.getFullVariableName = getFullVariableName;
const getShortVariableName = (varName) => varName.split(".").pop();
exports.getShortVariableName = getShortVariableName;
//# sourceMappingURL=util.js.map